=========
 History
=========

1.0.1
=====

- Document installation/usage with conda and containers by @natefoo in https://github.com/galaxyproject/galaxy-upload/pull/7
- Use click to require file arg to exist by @natefoo in https://github.com/galaxyproject/galaxy-upload/pull/9
- Pin tuspy to !=1.0.1 due to issue with upload_chunk(). by @natefoo in https://github.com/galaxyproject/galaxy-upload/pull/10

1.0.0
=====

- Initial release

0.0.1
=====

- Initial prerelease for comment and testing
